diff --git a/ede-panel/menu.h b/ede-panel/menu.h
index 540af18..f62a3fa 100644
--- a/ede-panel/menu.h
+++ b/ede-panel/menu.h
@@ -31,7 +31,7 @@ static const char default_menu[] =
- \n\
About\n\
\n\
- - \n\
+
- \n\
Run\n\
\n\
- \n\
diff --git a/ede-panel/workpanel.cpp b/ede-panel/workpanel.cpp
index e8ee036..d08b41c 100644
--- a/ede-panel/workpanel.cpp
+++ b/ede-panel/workpanel.cpp
@@ -188,7 +188,7 @@ void clockRefresh(void *)
void runUtility(Fl_Widget *, char *pCommand)
{
char cmd[256];
- snprintf (cmd, sizeof(cmd)-1, "elauncher %s", pCommand);
+ snprintf (cmd, sizeof(cmd)-1, "ede-launch %s", pCommand);
fl_start_child_process(cmd, false);
}
@@ -355,7 +355,7 @@ void startUtility(Fl_Button *, void *pName)
pGlobalConfig.get("Panel", (char*)pName, value, "");
if(!pGlobalConfig.error() && !value.empty()) {
- value = "elauncher \""+value;
+ value = "ede-launch \""+value;
value += "\"";
fl_start_child_process(value, false);
}
@@ -432,7 +432,7 @@ void cb_run_app(Fl_Input *i, void*)
Fl_String exec(i->value());
if ((exec == "") || (exec == " "))
return;
- exec = "elauncher \""+exec;
+ exec = "ede-launch \""+exec;
exec += "\"";
fl_start_child_process(exec, false);
diff --git a/ede-panel/mainmenu.cpp b/ede-panel/mainmenu.cpp
index 67f049a..a568256 100644
--- a/ede-panel/mainmenu.cpp
+++ b/ede-panel/mainmenu.cpp
@@ -200,12 +200,12 @@ void MainMenu::clear_favourites()
%v the name of the Device entry in the desktop file
*/
// This function is now implemented in elauncher
void MainMenu::resolve_program(Fl_String cmd)
{
char pRun[FL_PATH_MAX];
- snprintf(pRun, sizeof(pRun)-1, "elauncher \"%s\"", cmd.c_str());
+ snprintf(pRun, sizeof(pRun)-1, "ede-launch \"%s\"", cmd.c_str());
fl_start_child_process(pRun, false);
}
@@ -200,12 +200,12 @@ void MainMenu::clear_favourites()
%v the name of the Device entry in the desktop file
*/
-// This function is now implemented in elauncher
+// This function is now implemented in ede-launch
void MainMenu::resolve_program(Fl_String cmd)
{